ZKNetworkError class

An exception thrown for network-related errors during communication.

Inheritance

Constructors

ZKNetworkError(String message)
Creates a new ZKNetworkError with the given message.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A message describing the error.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited